[git] gnupg-doc - branch, master, updated. 22fce826b8aec87f80861acd583fed2adbdc80c5

by Justus Winter cvs at cvs.gnupg.org
Wed Jan 11 12:05:35 CET 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "The GnuPG website and other docs".

The branch, master has been updated
       via  22fce826b8aec87f80861acd583fed2adbdc80c5 (commit)
       via  c96cd8d6fcb47f281414966f048e0c4e61561307 (commit)
       via  5d9e4b2972a2d7fb9859240e4d3861d4f5f943f1 (commit)
       via  7baf4445fe3fa7119970bd3f1d7b6ea1d22ace06 (commit)
       via  e83f04fdf5ebd962958228fd8ebbbb263615bb35 (commit)
       via  f82f0c36c69dc8099d447e640e062b2eaed4dfd9 (commit)
      from  537908a28758e0816ed956182a6a84981764401e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 22fce826b8aec87f80861acd583fed2adbdc80c5
Author: Justus Winter <justus at g10code.com>
Date:   Wed Jan 11 12:02:51 2017 +0100

    jenkins: add glue for testing on a windows vm
    
    Signed-off-by: Justus Winter <justus at g10code.com>

diff --git a/misc/jenkins/bin/build.bash b/misc/jenkins/bin/build.bash
index eb5d973..72f18ab 100755
--- a/misc/jenkins/bin/build.bash
+++ b/misc/jenkins/bin/build.bash
@@ -171,6 +171,8 @@ case "$XTARGET" in
 	case "$JOB_NAME" in
 		gnupg/*|gnupg-2.2/*)
 			bash /home/jenkins/bin/make-windows-cd.sh
+			# We need to pass the absolute path of the iso.
+			bash $HOME/bin/run-tests-w32.bash "$(readlink -f gnupg-test.iso)" || true
 			;;
 	esac
         ;;
diff --git a/misc/jenkins/bin/gnupg-2.0-w32.patch b/misc/jenkins/bin/gnupg-2.0-w32.patch
new file mode 100644
index 0000000..0cd6e59
--- /dev/null
+++ b/misc/jenkins/bin/gnupg-2.0-w32.patch
@@ -0,0 +1,21 @@
+diff --git a/autogen.sh b/autogen.sh
+index 605babfa9..1a9654f0d 100755
+--- a/autogen.sh
++++ b/autogen.sh
+@@ -87,15 +87,7 @@ if test "$1" = "--build-w32"; then
+     $tsdir/configure --enable-maintainer-mode --prefix=${w32root}  \
+              --host=${host} --build=${build} \
+              --enable-gpgtar \
+-             --with-gpg-error-prefix=${w32root} \
+-	     --with-ksba-prefix=${w32root} \
+-	     --with-libgcrypt-prefix=${w32root} \
+-	     --with-libassuan-prefix=${w32root} \
+-	     --with-zlib=${w32root} \
+-	     --with-regex=${w32root} \
+-             --with-pth-prefix=${w32root} \
+-             --with-libiconv-prefix=${w32root} \
+-             --with-adns=${w32root} "$@"
++	     "$@"
+     rc=$?
+     exit $rc
+ fi
diff --git a/misc/jenkins/bin/gnupg-2.2-w32.patch b/misc/jenkins/bin/gnupg-2.2-w32.patch
new file mode 120000
index 0000000..d829c6e
--- /dev/null
+++ b/misc/jenkins/bin/gnupg-2.2-w32.patch
@@ -0,0 +1 @@
+gnupg-w32.patch
\ No newline at end of file
diff --git a/misc/jenkins/bin/gnupg-w32.patch b/misc/jenkins/bin/gnupg-w32.patch
new file mode 100644
index 0000000..1927ceb
--- /dev/null
+++ b/misc/jenkins/bin/gnupg-w32.patch
@@ -0,0 +1,18 @@
+diff --git a/autogen.rc b/autogen.rc
+index 36948178f..4aa1993d8 100644
+--- a/autogen.rc
++++ b/autogen.rc
+@@ -15,13 +15,6 @@ esac
+ case "$myhost" in
+   w32)
+     configure_opts="
+-      --with-gpg-error-prefix=@SYSROOT@
+-      --with-ksba-prefix=@SYSROOT@
+-      --with-libgcrypt-prefix=@SYSROOT@
+-      --with-libassuan-prefix=@SYSROOT@
+-      --with-zlib=@SYSROOT@
+-      --with-regex=@SYSROOT@
+-      --with-npth-prefix=@SYSROOT@
+       --disable-g13
+       "
+     ;;
diff --git a/misc/jenkins/bin/run-tests-w32.bash b/misc/jenkins/bin/run-tests-w32.bash
new file mode 100755
index 0000000..44e303d
--- /dev/null
+++ b/misc/jenkins/bin/run-tests-w32.bash
@@ -0,0 +1,69 @@
+#!/bin/bash
+
+# Locking.
+exec 9<"$0"
+echo -n "Aquiring lock on $0... "
+if ! flock --timeout 15 9 ; then
+    echo "failed!"
+    exit 1
+fi
+echo "ok."
+
+set -ex
+
+URI="qemu:///system"
+GUEST="win8.1"
+GUEST_CDROM="sda"
+SSH="gpg at 192.168.122.117"
+
+function vdo() {
+    virsh -c "$URI" "$@"
+}
+
+function vssh() {
+    # OpenSSH on Windows does not cope well with a closed stdin.
+    timeout </dev/zero 10m ssh "$SSH" "$@"
+}
+
+function vping() {
+    if ssh </dev/zero >/dev/null 2>&1 -oConnectTimeout=1 \
+                                      "$SSH" "echo pong" ; then
+	return 0
+    else
+	return 1
+    fi
+}
+
+function vwait() {
+    echo >&2 -n "Waiting for the machine to boot... "
+    while ! vping ; do echo >&2 -n . ; sleep 1 ; done
+}
+
+# Revert to current snapshot and start the machine.
+vdo snapshot-revert --current --force --running "$GUEST"
+
+# Insert the CD.
+vdo change-media --update "$GUEST" "$GUEST_CDROM" "$1"
+
+set +x
+vwait
+set -x
+
+#sleep 5 # XXX: Let things settle.
+
+if [ "$2" ]; then
+    scp "$2" "$SSH:"
+    sleep 1 # XXX: openssh on windows is a bit fragile...
+    time vssh "cmd /c $(basename $2)"
+else
+    time vssh "cmd /c d:/run-tests.bat"
+fi
+
+sleep 1 # XXX: openssh on windows is a bit fragile...
+
+# The scp server is a bit fragile as well, and I believe globbing does
+# not work.  Simply use gpgtar.
+vssh 'powershell -Command "cd c:\temp\logs ; d:/gnupg/gpgtar.exe --create ."' | tar x --warning=no-timestamp
+
+# Shutdown.
+vdo shutdown "$GUEST"
diff --git a/misc/jenkins/bin/run-tests.bat b/misc/jenkins/bin/run-tests.bat
index d88e197..adef960 100644
--- a/misc/jenkins/bin/run-tests.bat
+++ b/misc/jenkins/bin/run-tests.bat
@@ -1,27 +1,21 @@
 @echo off
-cd /d d:\
 
-set TARGET=gnupg-test
-
-set GNUPGHOME=c:/%TARGET%/tests/openpgp
-c:/%TARGET%/gpg-connect-agent.exe killagent /bye
-rem is there a nicer way to sleep?
-ping -n 1 localhost > nul
-set GNUPGHOME=
-
-rmdir /q /s c:\%TARGET%
-mkdir c:\%TARGET%
-xcopy /q /s d:\gnupg c:\%TARGET%
-
-set GPGSCM_PATH=c:/%TARGET%/tests/gpgscm;c:/%TARGET%/tests/openpgp
+set BIN_PREFIX=d:\gnupg
+set GPGSCM_PATH=%BIN_PREFIX%/tests/gpgscm;%BIN_PREFIX%/tests/openpgp
 set EXEEXT=.exe
-set srcdir=/%TARGET%/tests/openpgp
-set BIN_PREFIX=c:/%TARGET%
+set srcdir=%BIN_PREFIX%/tests/openpgp
 set TMP=c:\temp
+set WD=c:\temp\logs
 mkdir %TMP%
+mkdir %WD%
+
+cd /d %BIN_PREFIX%
+%BIN_PREFIX%\gpgscm.exe --verbose tests/gpgscm/t-child.scm
+
+cd /d %WD%
 
-cd /d c:\%TARGET%
-c:\%TARGET%\gpgscm.exe --verbose tests/gpgscm/t-child.scm
+rem the gpgtar.scm is acting up (looping), and we don't deal with that
+rem well atm, so we simply omit it
 
-cd /d c:\%TARGET%\tests\openpgp
-c:\%TARGET%\gpgscm.exe run-tests.scm --shared version.scm mds.scm decrypt.scm decrypt-dsa.scm sigs.scm sigs-dsa.scm encrypt.scm encrypt-dsa.scm seat.scm clearsig.scm encryptp.scm detach.scm detachm.scm armsigs.scm armencrypt.scm armencryptp.scm signencrypt.scm signencrypt-dsa.scm armsignencrypt.scm armdetach.scm armdetachm.scm genkey1024.scm conventional.scm conventional-mdc.scm multisig.scm verify.scm gpgv-forged-keyring.scm armor.scm import.scm ecc.scm 4gb-packet.scm tofu.scm gpgtar.scm use-exact-key.scm default-key.scm export.scm ssh.scm quick-key-manipulation.scm issue2015.scm issue2346.scm issue2417.scm issue2419.scm
+echo Running tests...
+%BIN_PREFIX%\gpgscm.exe %srcdir%/run-tests.scm --parallel version.scm enarmor.scm mds.scm decrypt.scm decrypt-multifile.scm decrypt-dsa.scm decrypt-session-key.scm sigs.scm sigs-dsa.scm encrypt.scm encrypt-multifile.scm encrypt-dsa.scm compression.scm seat.scm clearsig.scm encryptp.scm detach.scm detachm.scm armsigs.scm armencrypt.scm armencryptp.scm signencrypt.scm signencrypt-dsa.scm armsignencrypt.scm armdetach.scm armdetachm.scm genkey1024.scm conventional.scm conventional-mdc.scm multisig.scm verify.scm verify-multifile.scm gpgv-forged-keyring.scm armor.scm import.scm import-revocation-certificate.scm ecc.scm 4gb-packet.scm tofu.scm use-exact-key.scm default-key.scm export.scm ssh-import.scm ssh-export.scm quick-key-manipulation.scm key-selection.scm delete-keys.scm gpgconf.scm issue2015.scm issue2346.scm issue2417.scm issue2419.scm

commit c96cd8d6fcb47f281414966f048e0c4e61561307
Author: Justus Winter <justus at g10code.com>
Date:   Wed Jan 4 17:04:28 2017 +0100

    jenkins: tweak gnupg-2.0 configuration

diff --git a/misc/jenkins/bin/build.bash b/misc/jenkins/bin/build.bash
index 7616e59..eb5d973 100755
--- a/misc/jenkins/bin/build.bash
+++ b/misc/jenkins/bin/build.bash
@@ -151,7 +151,14 @@ case "$XTARGET" in
 	  ( cd .. && patch -p1 <"/home/jenkins/bin/$(dirname $JOB_NAME)-w32.patch" )
 	fi
 	# We need to point it to npth and adns then...
-	CONFIGUREFLAGS="${CONFIGUREFLAGS} --with-npth-prefix=$ORIGINAL_PREFIX --with-adns=$ORIGINAL_PREFIX"
+	case "$JOB_NAME" in
+	    gnupg/XTARGET=w32|gnupg-2.2/XTARGET=w32)
+		CONFIGUREFLAGS="${CONFIGUREFLAGS} --with-npth-prefix=$ORIGINAL_PREFIX --with-adns=$ORIGINAL_PREFIX"
+		;;
+	    gnupg-2.0/XTARGET=w32)
+		CONFIGUREFLAGS="${CONFIGUREFLAGS} --with-pth-prefix=$ORIGINAL_PREFIX --with-adns=$ORIGINAL_PREFIX"
+		;;
+	esac
 
         # gpg1's autogen.sh does not add --enable-maintainer-mode, so
         # version.texi is not generated.  we add it here to be sure.

commit 5d9e4b2972a2d7fb9859240e4d3861d4f5f943f1
Author: Justus Winter <justus at g10code.com>
Date:   Tue Jan 3 15:18:37 2017 +0100

    jenkins: use make -k check

diff --git a/misc/jenkins/bin/build.bash b/misc/jenkins/bin/build.bash
index 0f32883..7616e59 100755
--- a/misc/jenkins/bin/build.bash
+++ b/misc/jenkins/bin/build.bash
@@ -117,7 +117,7 @@ case "$XTARGET" in
 	           CXXFLAGS="$CXXFLAGS -fPIC -std=c++11"
         make $MAKEFLAGS
 
-        make check verbose=2 || true
+        make -k check verbose=2 || true
         # Jenkins looks for "tests? failed" to mark a build unstable,
         # hence || true here
 
@@ -134,7 +134,7 @@ case "$XTARGET" in
 	           CXXFLAGS="$CXXFLAGS $SANFLAGS -fPIC -std=c++11"
         $SCANBUILD make $MAKEFLAGS
 
-        make check verbose=2 || true
+        make -k check verbose=2 || true
         # Jenkins looks for "tests? failed" to mark a build unstable,
         # hence || true here
 

commit 7baf4445fe3fa7119970bd3f1d7b6ea1d22ace06
Author: Justus Winter <justus at g10code.com>
Date:   Tue Jan 3 15:18:00 2017 +0100

    jenkins: disable python bindings for the sanitizer target

diff --git a/misc/jenkins/bin/build.bash b/misc/jenkins/bin/build.bash
index 1dfe3f2..f5bad38 100755
--- a/misc/jenkins/bin/build.bash
+++ b/misc/jenkins/bin/build.bash
@@ -59,7 +59,7 @@ fi
 CONFIGUREFLAGS=
 SANFLAGS=""
 if [ "$(uname)" = Linux ]; then
-    # XXX: We should really have an analyzer target
+    # XXX: We should check if the sanitizers are available.
     SANFLAGS="-fsanitize=undefined -fsanitize=address"
 fi
 
@@ -109,6 +109,20 @@ cd obj
 # Switch on the different targets.
 case "$XTARGET" in
     native)
+        ../configure --prefix=$PREFIX --enable-maintainer-mode \
+	           $CONFIGUREFLAGS \
+	           "$CONFIGUREFLAGS_0" \
+	           CFLAGS="$CFLAGS -fPIC" \
+	           CXXFLAGS="$CXXFLAGS -fPIC -std=c++11"
+        make $MAKEFLAGS
+
+        make check verbose=2 || true
+        # Jenkins looks for "tests? failed" to mark a build unstable,
+        # hence || true here
+
+        make install
+        ;;
+    sanitizer)
 	# asan breaks the configure tests, so we disable it here.
         ASAN_OPTIONS=detect_leaks=0 \
         $SCANBUILD \

commit f82f0c36c69dc8099d447e640e062b2eaed4dfd9
Author: Justus Winter <justus at g10code.com>
Date:   Tue Jan 3 10:41:39 2017 +0100

    jenkins: use more jobs

diff --git a/misc/jenkins/bin/build.bash b/misc/jenkins/bin/build.bash
index e886ca1..1dfe3f2 100755
--- a/misc/jenkins/bin/build.bash
+++ b/misc/jenkins/bin/build.bash
@@ -43,10 +43,11 @@ git clean -fdx
 # Run out autogen - note that --force is not required due to the git clean.
 ./autogen.sh
 
-# Out current box seems to have cache coherency problems, thus we have
-# disabled all but one CPU.
-MAKEFLAGS="-j2"
+# Parallel jobs.
+MAKEFLAGS="-j6"
 
+# Parallel tests with our test suite.
+export TESTFLAGS="--parallel"
 
 SCANBUILD=
 if [ "$(uname)" = Linux ] \

-----------------------------------------------------------------------

Summary of changes:
 misc/jenkins/bin/build.bash          | 41 ++++++++++++++++-----
 misc/jenkins/bin/gnupg-2.0-w32.patch | 21 +++++++++++
 misc/jenkins/bin/gnupg-2.2-w32.patch |  1 +
 misc/jenkins/bin/gnupg-w32.patch     | 18 ++++++++++
 misc/jenkins/bin/run-tests-w32.bash  | 69 ++++++++++++++++++++++++++++++++++++
 misc/jenkins/bin/run-tests.bat       | 34 ++++++++----------
 6 files changed, 156 insertions(+), 28 deletions(-)
 create mode 100644 misc/jenkins/bin/gnupg-2.0-w32.patch
 create mode 120000 misc/jenkins/bin/gnupg-2.2-w32.patch
 create mode 100644 misc/jenkins/bin/gnupg-w32.patch
 create mode 100755 misc/jenkins/bin/run-tests-w32.bash


hooks/post-receive
diff --git a/misc/jenkins/bin/build.bash b/misc/jenkins/bin/build.bash
index f5bad38..0f32883 100755
--- a/misc/jenkins/bin/build.bash
+++ b/misc/jenkins/bin/build.bash
@@ -76,8 +76,9 @@ case "$JOB_NAME" in
         MAKEFLAGS="$MAKEFLAGS GPG=/usr/bin/gpg2"
         ;;
     *gpgme*)
-        # using libasan for python broke again, so disable the python bindings for the native build
-        if [ "$XTARGET" = native ] && [ "$label" != macos ]; then
+        # using libasan for python broke again, so disable the python
+        # bindings for the sanitizer build
+        if [ "$XTARGET" = sanitizer ]; then
             CONFIGUREFLAGS_0="--enable-languages=cpp qt"
         fi
         ;;

commit e83f04fdf5ebd962958228fd8ebbbb263615bb35
Author: Justus Winter <justus at g10code.com>
Date:   Tue Jan 3 13:22:26 2017 +0100

    jenkins: add a sanitizer target

-- 
The GnuPG website and other docs
http://git.gnupg.org




More information about the Gnupg-commits mailing list